==> haskell-foldl-1.3.2-1-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-foldl.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: foldl
version: 1.3.2
id: foldl-1.3.2-BGRT7HjGiX35g2tr0jImlB
key: foldl-1.3.2-BGRT7HjGiX35g2tr0jImlB
license: BSD3
copyright: 2013 Gabriel Gonzalez
maintainer: Gabriel439@gmail.com
synopsis: Composable, streaming, and efficient left folds
description:
    This library provides strict left folds that stream in constant
    memory, and you can combine folds using @Applicative@ style to derive new
    folds.  Derived folds still traverse the container just once and are often as
    efficient as hand-written folds.
category: Control
author: Gabriel Gonzalez
exposed: True
indefinite: False
exposed-modules:
    Control.Foldl Control.Foldl.ByteString Control.Foldl.Text
hidden-modules: Control.Foldl.Internal
abi: b31e209efc07720663f4f753385ee290
trusted: False
import-dirs: /usr/lib/ghc-8.2.1/site-local/foldl-1.3.2
library-dirs: /usr/lib/ghc-8.2.1/site-local/foldl-1.3.2
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.2.1/foldl-1.3.2
hs-libraries: HSfoldl-1.3.2-BGRT7HjGiX35g2tr0jImlB
depends:
    base-4.10.0.0 bytestring-0.10.8.2
    mwc-random-0.13.6.0-9isDaETTkAQ4w6DSIRGQbB
    primitive-0.6.2.0-V0ibjLQDdN6fcQS5bjLVg
    text-1.2.2.2-KYRZgO9N4MoJ4sC5lMiKTz transformers-0.5.2.0
    vector-0.12.0.1-CnPH69pDwM4A5esizlXfXi containers-0.5.10.2
    unordered-containers-0.2.8.0-KL4HUdwCmhYBQDTvY5v0GN
    hashable-1.2.6.1-5D85BzUWIsjDNuFvtLMWyk
    contravariant-1.4-1lqq0vqix8Y43XZ7Q5hTLe
    semigroups-0.18.3-6KPIVJcHqOOBHjBl8WA5LP
    profunctors-5.2.1-tcGHrJuwpB2Qib1uMFFo0
    comonad-5.0.2-AAFyIh6Dm39islDxts6T3
    vector-builder-0.3.3.1-8YVAJrkDNXw3KWd9wBlvvK
abi-depends: base-4.10.0.0=32d562aa6d04d35ac79a0f49c17325ff
             bytestring-0.10.8.2=4f0c9618a8f04261f970de9708e01603
             mwc-random-0.13.6.0-9isDaETTkAQ4w6DSIRGQbB=37879dc7727b997b0a1807fa5f0e56da
             primitive-0.6.2.0-V0ibjLQDdN6fcQS5bjLVg=998ed6e6951fb3231f40c732faa08c23
             text-1.2.2.2-KYRZgO9N4MoJ4sC5lMiKTz=42480b67fee41ad692110e11eaac57c4
             transformers-0.5.2.0=9705988bf0172d3bbbcdcaf65e1d842a
             vector-0.12.0.1-CnPH69pDwM4A5esizlXfXi=12d01284f86dd305f0b2cab827808cc2
             containers-0.5.10.2=e086202b65ca66a107fcba9d846fc3e0
             unordered-containers-0.2.8.0-KL4HUdwCmhYBQDTvY5v0GN=c3a6cf2eb5dea0a9b852305436978b94
             hashable-1.2.6.1-5D85BzUWIsjDNuFvtLMWyk=90545b19a76e197f153fb1577996b718
             contravariant-1.4-1lqq0vqix8Y43XZ7Q5hTLe=893af150e87a363f17ac42bee5d29045
             semigroups-0.18.3-6KPIVJcHqOOBHjBl8WA5LP=7bc502c1773a3f628e3db58cb706740b
             profunctors-5.2.1-tcGHrJuwpB2Qib1uMFFo0=a7e80b9d748c8bf1db214fda1cbc5e33
             comonad-5.0.2-AAFyIh6Dm39islDxts6T3=2e229087fcf32b235bcf466fea4261ee
             vector-builder-0.3.3.1-8YVAJrkDNXw3KWd9wBlvvK=b8443c659bd57c66989df6beded330ac
haddock-interfaces: /usr/share/doc/haskell-foldl/html/foldl.haddock
haddock-html: /usr/share/doc/haskell-foldl/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-foldl-1.3.3-1-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-foldl.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: foldl
version: 1.3.3
id: foldl-1.3.3-49VW3LzmspQ2MyVG57SLFx
key: foldl-1.3.3-49VW3LzmspQ2MyVG57SLFx
license: BSD3
copyright: 2013 Gabriel Gonzalez
maintainer: Gabriel439@gmail.com
synopsis: Composable, streaming, and efficient left folds
description:
    This library provides strict left folds that stream in constant
    memory, and you can combine folds using @Applicative@ style to derive new
    folds.  Derived folds still traverse the container just once and are often as
    efficient as hand-written folds.
category: Control
author: Gabriel Gonzalez
exposed: True
indefinite: False
exposed-modules:
    Control.Foldl Control.Foldl.ByteString Control.Foldl.Text
hidden-modules: Control.Foldl.Internal
abi: 5802dff2867d5eae64850cfa76f5dab2
trusted: False
import-dirs: /usr/lib/ghc-8.2.1/site-local/foldl-1.3.3
library-dirs: /usr/lib/ghc-8.2.1/site-local/foldl-1.3.3
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.2.1/foldl-1.3.3
hs-libraries: HSfoldl-1.3.3-49VW3LzmspQ2MyVG57SLFx
depends:
    base-4.10.0.0 bytestring-0.10.8.2
    mwc-random-0.13.6.0-9isDaETTkAQ4w6DSIRGQbB
    primitive-0.6.2.0-V0ibjLQDdN6fcQS5bjLVg
    text-1.2.2.2-KYRZgO9N4MoJ4sC5lMiKTz transformers-0.5.2.0
    vector-0.12.0.1-CnPH69pDwM4A5esizlXfXi containers-0.5.10.2
    unordered-containers-0.2.8.0-KL4HUdwCmhYBQDTvY5v0GN
    hashable-1.2.6.1-5D85BzUWIsjDNuFvtLMWyk
    contravariant-1.4-1lqq0vqix8Y43XZ7Q5hTLe
    semigroups-0.18.3-6KPIVJcHqOOBHjBl8WA5LP
    profunctors-5.2.1-tcGHrJuwpB2Qib1uMFFo0
    comonad-5.0.2-AAFyIh6Dm39islDxts6T3
    vector-builder-0.3.3.1-8YVAJrkDNXw3KWd9wBlvvK
abi-depends: base-4.10.0.0=32d562aa6d04d35ac79a0f49c17325ff
             bytestring-0.10.8.2=4f0c9618a8f04261f970de9708e01603
             mwc-random-0.13.6.0-9isDaETTkAQ4w6DSIRGQbB=37879dc7727b997b0a1807fa5f0e56da
             primitive-0.6.2.0-V0ibjLQDdN6fcQS5bjLVg=998ed6e6951fb3231f40c732faa08c23
             text-1.2.2.2-KYRZgO9N4MoJ4sC5lMiKTz=42480b67fee41ad692110e11eaac57c4
             transformers-0.5.2.0=9705988bf0172d3bbbcdcaf65e1d842a
             vector-0.12.0.1-CnPH69pDwM4A5esizlXfXi=12d01284f86dd305f0b2cab827808cc2
             containers-0.5.10.2=e086202b65ca66a107fcba9d846fc3e0
             unordered-containers-0.2.8.0-KL4HUdwCmhYBQDTvY5v0GN=c3a6cf2eb5dea0a9b852305436978b94
             hashable-1.2.6.1-5D85BzUWIsjDNuFvtLMWyk=90545b19a76e197f153fb1577996b718
             contravariant-1.4-1lqq0vqix8Y43XZ7Q5hTLe=893af150e87a363f17ac42bee5d29045
             semigroups-0.18.3-6KPIVJcHqOOBHjBl8WA5LP=7bc502c1773a3f628e3db58cb706740b
             profunctors-5.2.1-tcGHrJuwpB2Qib1uMFFo0=a7e80b9d748c8bf1db214fda1cbc5e33
             comonad-5.0.2-AAFyIh6Dm39islDxts6T3=2e229087fcf32b235bcf466fea4261ee
             vector-builder-0.3.3.1-8YVAJrkDNXw3KWd9wBlvvK=b8443c659bd57c66989df6beded330ac
haddock-interfaces: /usr/share/doc/haskell-foldl/html/foldl.haddock
haddock-html: /usr/share/doc/haskell-foldl/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
